@@ -3,6 +3,9 @@
 /// Errors that occur while working with [`crate::types::vector::Vector`]
 #[derive(Debug)]
 pub enum VectorError {
+    /// Occurs when an operation that requires data in a [`crate::types::vector::Vector`] is
+    /// requested with an empty [`crate::types::vector::Vector`]
+    EmptyVectorError(String),
     /// Occurs when there is invalid data during an attempt to convert
     /// from [`slice`] data.
     TryFromSliceError(String),
@@ -16,6 +19,9 @@ pub enum VectorError {
 impl std::fmt::Display for VectorError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         match self {
+            VectorError::EmptyVectorError(s) => {
+                write!(f, "VectorError::EmptyVectorError: {}", s)
+            }
             VectorError::TryFromVecError(s) => {
                 write!(f, "VectorError::TryFromVecError: {}", s)
             }
